@@ -499,8 +499,8 @@ AllocationTypeType = Literal["used"]
 AllowsMultipleInstanceTypesType = Literal["off", "on"]
 AnalysisStatusType = Literal["failed", "running", "succeeded"]
 ApplianceModeSupportValueType = Literal["disable", "enable"]
-ArchitectureTypeType = Literal["arm64", "i386", "x86_64", "x86_64_mac"]
-ArchitectureValuesType = Literal["arm64", "i386", "x86_64", "x86_64_mac"]
+ArchitectureTypeType = Literal["arm64", "arm64_mac", "i386", "x86_64", "x86_64_mac"]
+ArchitectureValuesType = Literal["arm64", "arm64_mac", "i386", "x86_64", "x86_64_mac"]
 AssociatedNetworkTypeType = Literal["vpc"]
 AssociationStatusCodeType = Literal[
     "associated", "associating", "association-failed", "disassociated", "disassociating"
@@ -1431,9 +1431,13 @@ InstanceTypeType = Literal[
     "t4g.nano",
     "t4g.small",
     "t4g.xlarge",
+    "trn1.2xlarge",
+    "trn1.32xlarge",
     "u-12tb1.112xlarge",
     "u-12tb1.metal",
+    "u-18tb1.112xlarge",
     "u-18tb1.metal",
+    "u-24tb1.112xlarge",
     "u-24tb1.metal",
     "u-3tb1.56xlarge",
     "u-6tb1.112xlarge",
